import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';

class ButtonBox extends StatelessWidget {
  const ButtonBox(this.schema, {Key? key}) : super(key: key);
  final ButtonSchema schema;

  void _handleButtonPressed () {
    if (schema.interactiveTrigger == 'click') {
      if (schema.interactiveType == 'link') {
        if (schema.interactiveData.isNotEmpty) {
          launch(schema.interactiveData);
        }
      }
    }
  }
  @override
  Widget build(BuildContext context) {
    // TextButton or OutlinedButton
    return TextButton(
      style: ButtonStyle(
        padding: MaterialStateProperty.all(schema.padding),
        textStyle: MaterialStateProperty.all(
          schema.textStyle
        ),
        backgroundColor: MaterialStateProperty.all(
          schema.bgColor
        ),
        overlayColor: MaterialStateProperty.all(
          schema.fgColor
        ),
        // todo why shadowColor take no effect
        // shadowColor: MaterialStateProperty.all(
        //   Colors.red
        // ),
        // todo why foregroundColor take no effect
        // foregroundColor: MaterialStateProperty.all(
        //   Colors.yellow
        // ),
        shape: MaterialStateProperty.all(
          RoundedRectangleBorder(
            side: BorderSide(
              color: schema.borderColor,
              width: schema.borderWidth,
              style: schema.borderWidth == 0 ? BorderStyle.none : BorderStyle.solid
            ),
            borderRadius: BorderRadius.all(
              Radius.circular(schema.borderRadius)
            )
          )
        ),
        alignment: schema.alignment
      ),
      onPressed: _handleButtonPressed,
      child: SizedBox(
        width: double.infinity,
        child: Text(
          schema.data,
          style: schema.textStyle,
          textAlign: schema.textAlign
        ),
      )
    );
  }
}

class ButtonSchema {
  const ButtonSchema({
    Key? key,
    required this.data,
    required this.padding,
    required this.bgColor,
    required this.fgColor,
    required this.borderColor,
    required this.borderRadius,
    required this.borderWidth,

    required this.textStyle,
    required this.alignment,
    required this.textAlign,
    required this.interactiveTrigger,
    required this.interactiveType,
    required this.interactiveData,
  });
  final String data;
  final EdgeInsets padding;
  final Color bgColor;
  final Color fgColor;
  final Color borderColor;
  final double borderRadius;
  final double borderWidth;

  final TextStyle textStyle;
  final Alignment alignment;
  final TextAlign textAlign;
  final String interactiveTrigger;
  final String interactiveType;
  final String interactiveData;
}